@@ -2,4 +2,4 @@
 
 import rvcprint
 
-rvcprint.bdmodel('IBVS-partitioned.bd')
+rvcprint.bdmodel('IBVS-holonomic.bd')
